California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Choose an Election Cycle: 2021 through 2022 Historical 2019 through 2020 2017 through 2018 2015 through 2016 2013 through 2014 2011 through 2012 2009 through 2010 2007 through 2008 2005 through 2006 2003 through 2004 2001 through 2002 1999 through 2000
HERE ARE YOUR RESULTS: Election Dates (Dates appear according to the Election Cycle above) 2005 - 2006 Election Dates: 1. SPECIAL ELECTION Tuesday, 9/13/05 2. SPECIAL ELECTION Tuesday, 11/8/05 3. SPECIAL ELECTION Tuesday, 4/11/06 4. SPECIAL ELECTION RUNOFF Tuesday, 6/6/06 5. PRIMARY ELECTION Tuesday, 6/6/06 6. GENERAL ELECTION Tuesday, 11/7/06
If you are searching for campaign finance information related to a specific office this is the place to begin. Included are officeholders for Governor, Lieutenant Governor, Secretary of State, Attorney General, State Controller, State Treasurer, Insurance Commissioner, State Superintendent of Public Instruction, Board of Equalization, State Senate, and State Assembly. Here you will find their names, campaign committees, and other information.
STATEWIDE OFFICES
GOVERNOR
SCHWARZENEGGER, ARNOLD
| LIEUTENANT GOVERNOR
BUSTAMANTE, CRUZ M.
SECRETARY OF STATE
MC PHERSON, BRUCE
| CONTROLLER
WESTLY, STEVE
TREASURER
ANGELIDES, PHIL
| ATTORNEY GENERAL
LOCKYER, BILL
SUPERINTENDENT OF PUBLIC INSTRUCTION
O'CONNELL, JACK
| INSURANCE COMMISSIONER
GARAMENDI, JOHN
BOARD OF EQUALIZATION
MEMBER BOARD OF EQUALIZATION 01
YEE, BETTY T.
| MEMBER BOARD OF EQUALIZATION 02
LEONARD, BILL
MEMBER BOARD OF EQUALIZATION 03
PARRISH, CLAUDE
| MEMBER BOARD OF EQUALIZATION 04
CHIANG, JOHN
SENATE DISTRICTS
STATE SENATE 01
COX, DAVE
| STATE SENATE 02
CHESBRO, WESLEY
STATE SENATE 03
MIGDEN, CAROLE
| STATE SENATE 04
AANESTAD, SAMUEL M.
STATE SENATE 05
MACHADO, MICHAEL J.
| STATE SENATE 06
ORTIZ, DEBORAH V.
STATE SENATE 07
TORLAKSON, TOM
| STATE SENATE 08
SPEIER, JACQUELINE
STATE SENATE 09
PERATA, DON
| STATE SENATE 10
FIGUEROA, LIZ
STATE SENATE 11
SIMITIAN, S. JOSEPH
| STATE SENATE 12
DENHAM, JEFF
STATE SENATE 13
ALQUIST, ELAINE
| STATE SENATE 14
POOCHIGIAN, CHUCK
STATE SENATE 15
MALDONADO, ABEL
| STATE SENATE 16
FLOREZ, DEAN
STATE SENATE 17
RUNNER, GEORGE C.
| STATE SENATE 18
ASHBURN, ROY
STATE SENATE 19
MC CLINTOCK, THOMAS
| STATE SENATE 20
ALARCON, RICHARD
STATE SENATE 21
SCOTT, JACK
| STATE SENATE 22
CEDILLO, GILBERT
STATE SENATE 23
KUEHL, SHEILA J.
| STATE SENATE 24
ROMERO, GLORIA
STATE SENATE 25
VINCENT, EDWARD
| STATE SENATE 26
MURRAY, KEVIN
STATE SENATE 27
LOWENTHAL, ALAN
| STATE SENATE 28
BOWEN, DEBRA
STATE SENATE 29
MARGETT, ROBERT
| STATE SENATE 30
ESCUTIA, MARTHA M.
STATE SENATE 31
DUTTON, BOB
| STATE SENATE 32
SOTO, NELL
STATE SENATE 33
ACKERMAN, RICHARD
| STATE SENATE 34
DUNN, JOSEPH
STATE SENATE 35
CAMPBELL, JOHN B.T.
| STATE SENATE 36
HOLLINGSWORTH, DENNIS
STATE SENATE 37
BATTIN JR., JAMES F.
| STATE SENATE 38
MORROW, BILL
STATE SENATE 39
KEHOE, CHRISTINE
| STATE SENATE 40
DUCHENY, DENISE MORENO
ASSEMBLY DISTRICTS
ASSEMBLY 01
BERG, PATTY
| ASSEMBLY 02
LA MALFA, DOUG
ASSEMBLY 03
KEENE, RICHARD J.
| ASSEMBLY 04
LESLIE, R. TIM
ASSEMBLY 05
NIELLO, ROGER
| ASSEMBLY 06
NATION, JOE
ASSEMBLY 07
EVANS, NOREEN M.
| ASSEMBLY 08
WOLK, LOIS
ASSEMBLY 09
JONES, DAVE
| ASSEMBLY 10
NAKANISHI, ALAN S.
ASSEMBLY 11
CANCIAMILLA, JOSEPH
| ASSEMBLY 12
YEE, LELAND Y.
ASSEMBLY 13
LENO, MARK
| ASSEMBLY 14
HANCOCK, LONI
ASSEMBLY 15
HOUSTON, GUY
| ASSEMBLY 16
CHAN, WILMA
ASSEMBLY 17
MATTHEWS, BARBARA
| ASSEMBLY 18
KLEHS, JOHAN
ASSEMBLY 19
MULLIN, GENE R.
| ASSEMBLY 20
TORRICO, ALBERTO
ASSEMBLY 21
RUSKIN, IRA
| ASSEMBLY 22
LIEBER, SALLY
ASSEMBLY 23
COTO, JOE
| ASSEMBLY 24
COHN, REBECCA
ASSEMBLY 25
COGDILL, DAVID E.
| ASSEMBLY 26
AGHAZARIAN, GREG
ASSEMBLY 27
LAIRD, JOHN S.
| ASSEMBLY 28
SALINAS, SIMON
ASSEMBLY 29
VILLINES, MICHAEL N.
| ASSEMBLY 30
PARRA, NICOLE
ASSEMBLY 31
ARAMBULA, JUAN
| ASSEMBLY 32
MC CARTHY, KEVIN
ASSEMBLY 33
BLAKESLEE, SAM
| ASSEMBLY 34
MAZE, BILL
ASSEMBLY 35
NAVA, PEDRO I.
| ASSEMBLY 36
RUNNER, SHARON
ASSEMBLY 37
STRICKLAND, AUDRA
| ASSEMBLY 38
RICHMAN, KEITH STUART
ASSEMBLY 39
MONTANEZ, CINDY
| ASSEMBLY 40
LEVINE, LLOYD
ASSEMBLY 41
PAVLEY, FRAN
| ASSEMBLY 42
KORETZ, PAUL
ASSEMBLY 43
FROMMER, DARIO
| ASSEMBLY 44
LIU, CAROL
ASSEMBLY 45
GOLDBERG, JACKIE
| ASSEMBLY 46
NUNEZ, FABIAN
ASSEMBLY 47
BASS, KAREN
| ASSEMBLY 48
RIDLEY-THOMAS, MARK
ASSEMBLY 49
CHU, JUDY
| ASSEMBLY 50
DE LA TORRE, HECTOR
ASSEMBLY 51
HORTON, JEROME E.
| ASSEMBLY 52
DYMALLY, MERVYN M.
ASSEMBLY 53
LIEU, TED
| ASSEMBLY 54
KARNETTE, BETTY
ASSEMBLY 55
OROPEZA, JENNY
| ASSEMBLY 56
BERMUDEZ, RUDY
ASSEMBLY 57
CHAVEZ, EDWARD "ED"
| ASSEMBLY 58
CALDERON, RONALD
ASSEMBLY 59
MOUNTJOY, DENNIS
| ASSEMBLY 60
HUFF, ROBERT 'BOB'
ASSEMBLY 61
MC LEOD, GLORIA NEGRETE
| ASSEMBLY 62
BACA JR., JOE
ASSEMBLY 63
EMMERSON, BILL
| ASSEMBLY 64
BENOIT, JOHN J.
ASSEMBLY 65
BOGH, RUSSELL V.
| ASSEMBLY 66
HAYNES, RAYMOND N.
ASSEMBLY 67
| ASSEMBLY 68
TRAN, VAN
ASSEMBLY 69
UMBERG, THOMAS J.
| ASSEMBLY 70
DE VORE, CHARLES S.
ASSEMBLY 71
SPITZER, TODD
| ASSEMBLY 72
DAUCHER, LYNN
ASSEMBLY 73
WALTERS, MIMI
| ASSEMBLY 74
WYLAND, MARK B.
ASSEMBLY 75
PLESCIA, GEORGE A.
| ASSEMBLY 76
SALDANA, LORI
ASSEMBLY 77
LA SUER, JAY
| ASSEMBLY 78
HORTON, SHIRLEY
ASSEMBLY 79
VARGAS, JUAN C.
| ASSEMBLY 80
GARCIA, BONNIE